@@ -1,3 +1,4 @@
+import codecs
 import datetime
 import logging
 import os
@@ -10,7 +11,6 @@ import click
 import deepsecurity
 import requests
 import urllib3
-import urllib3
 import yaml
 from rich.console import Console, OverflowMethod
 from rich.logging import RichHandler
@@ -31,7 +31,7 @@ from dsmigrator.lists import (
     schedule_listmaker,
     stateful_listmaker,
 )
-from dsmigrator.logging import console, error_console, error_console, log, filename
+from dsmigrator.logging import console, error_console, filename, log
 from dsmigrator.loginspection import li_config_transform
 from dsmigrator.policies import (
     AddPolicy,
@@ -44,9 +44,9 @@ from dsmigrator.system_settings import settings_transfer
 from dsmigrator.tasks import ebt_listmaker, st_listmaker
 
 
-def ascii_art():
-    console.print(
-        """\
+# Welcome Banner
+console.print(
+    """\
                                                       
               %###################,               
           #############################           
@@ -68,27 +68,43 @@ def ascii_art():
            \\###########################           
                ###################               
     """,
-        style="bold red",
-        overflow="crop",
-    )
+    style="bold red",
+    overflow="crop",
+)
+console.print(
+    "Welcome to the Trend Micro Policy Migration Tool",
+    style="bold red",
+)
 
 
-# override the click invoke method
-def CommandWithConfigFile(config_file_param_name):
-    class CustomCommandClass(click.Command):
-        def invoke(self, ctx):
-            config_file = ctx.params[config_file_param_name]
-            if config_file is not None:
-                with open(config_file) as f:
-                    config_data = yaml.safe_load(f)
-                    for param, value in ctx.params.items():
-                        if value is None and param in config_data:
-                            ctx.params[param] = config_data[param]
-                            ctx.params[param].prompt = None
+# Init helpers
 
-            return super(CustomCommandClass, self).invoke(ctx)
 
-    return CustomCommandClass
+def validate_url(ctx, param, url: str) -> str:
+    """
+    Makes sure urls start with 'http' and end with a '/'
+
+    Args:
+        ctx: necessary for click
+        param: necessary for click
+        url (str): url string
+
+    Raises:
+        click.BadParameter: kicks the user out of the cli and lets them know
+                            about the specific error
+
+    Returns:
+        str: a sanitized url
+    """
+    try:
+        assert url[0:4] == "http"
+        if url[-1] != "/":
+            url = url + "/"
+        return url
+    except:
+        raise click.BadParameter(
+            "DSM url must start with http, please double-check input"
+        )
 
 
 def validate_api_keys(ctx, param, api_key):
@@ -113,11 +129,27 @@ def validate_api_keys(ctx, param, api_key):
         )
 
 
-ascii_art()
-console.print(
-    "Welcome to the Trend Micro Policy Migration Tool",
-    style="bold red",
-)
+# override the click invoke method
+
+
+def CommandWithConfigFile(config_file_param_name):
+    class CustomCommandClass(click.Command):
+        def invoke(self, ctx):
+            config_file = ctx.params[config_file_param_name]
+            if config_file is not None:
+                with open(config_file) as f:
+                    config_data = yaml.safe_load(f)
+                    for param, value in ctx.params.items():
+                        if value is None and param in config_data:
+                            ctx.params[param] = config_data[param]
+                            ctx.params[param].prompt = None
+
+            return super(CustomCommandClass, self).invoke(ctx)
+
+    return CustomCommandClass
+
+
+# pass options
 
 
 @click.command(cls=CommandWithConfigFile("config_file"))
@@ -125,6 +157,7 @@ console.print(
 @click.option(
     "-ou",
     "--original-url",
+    callback=validate_url,
     prompt="Old DSM address and port (e.g. https://10.10.10.10:4119/)",
     help="A resolvable FQDN for the old DSM, with port number (e.g. https://192.168.1.1:4119/)",
     envvar="ORIGINAL_URL",
@@ -171,6 +204,11 @@ console.print(
     is_flag=True,
     help="Suppress the InsecureRequestWarning for self-signed certificates",
 )
+@click.option(
+    "-f",
+    "--filter",
+    help="A list of policy names in form '[name, name, ...]' which are the only ones which will be transferred.",
+)
 # @click.option(
 #     "-c",
 #     "--cert",
@@ -178,6 +216,10 @@ console.print(
 #     show_default=True,
 #     help="(Optional) Allows the use of a cert file",
 # )
+
+# Main tool
+
+
 def main(
     config_file,
     original_url,
@@ -188,6 +230,7 @@ def main(
     insecure,
     tasks,
     delete_policies,
+    filter,
 ):
     """Moves your on-prem DS deployment to the cloud!"""
     OLD_API_KEY = original_api_key
@@ -203,10 +246,32 @@ def main(
         console.rule("Delete C1 Policies")
         delete_cloud_one_policies(NEW_API_KEY)
 
-    old_policy_id_list = ListAllPolicy(OLD_HOST, OLD_API_KEY)
+    old_policy_id_list, oldpolicynameid_dict = ListAllPolicy(OLD_HOST, OLD_API_KEY)
+    # filter out unwanted policies
+    if filter:
+        console.rule("Filter Out Unwanted Policies")
+        if (filter[0] != "[") or (filter[-1] != "]"):
+            log.error(
+                "Please pass in filter names in form '[name1, name2, ...]', making note of brackets"
+            )
+            raise TypeError
+        name_list = filter[1:-1].split(", ")
+        old_policy_id_list = []
+        for desired_policy in name_list:
+            # validate
+            if '"' in desired_policy:
+                log.error(
+                    "Please pass in filter names in form '[name1, name2, ...]', making note of quoting conventions"
+                )
+                raise TypeError
+            desired_id = oldpolicynameid_dict.get(desired_policy)
+            if desired_id is not None:
+                old_policy_id_list.append(desired_id)
+        console.log(f"New desired policy IDs: {old_policy_id_list}")
 
     console.save_text(filename, clear=False)
     console.rule("Initial Data Collection")
+
     antimalwareconfig, allofpolicy = GetPolicy(
         old_policy_id_list, OLD_HOST, OLD_API_KEY
     )
@@ -243,7 +308,7 @@ def main(
     t1contextid, t2contextid = context_listmaker(
         OLD_HOST, OLD_API_KEY, NEW_HOST, NEW_API_KEY
     )
-    t1scheduleid, t2scheduleid = schedule_listmaker(
+    schedule_id_dict, t1scheduleid, t2scheduleid = schedule_listmaker(
         OLD_HOST, OLD_API_KEY, NEW_HOST, NEW_API_KEY
     )
 
@@ -303,6 +368,7 @@ def main(
         amallfileextentionnew,
         amfilelist,
         amallfilelistnew,
+        schedule_id_dict,
         NEW_HOST,
         NEW_API_KEY,
     )
