@@ -35,6 +35,7 @@ def am_validate_create(
     amallfileextentionnew,
     amfilelist,
     amallfilelistnew,
+    schedule_id_dict,
     NEW_HOST,
     NEW_API_KEY,
 ):
@@ -48,11 +49,11 @@ def am_validate_create(
         amallfilelistnew,
     )
 
-    # renamed_allamconfig = RenameAmConfig(mod_allamconfig)
-
     allamconfigdict = AmconfigTenant2(mod_allamconfig, NEW_API_KEY)
 
-    aop_replace_am_configs = AmReplaceConfig(allofpolicy, allamconfigdict)
+    aop_replace_am_configs = AmReplaceConfig(
+        allofpolicy, allamconfigdict, schedule_id_dict
+    )
     final = aop_replace_am_configs
     return final
 
@@ -72,7 +73,6 @@ def AMconfigtenant1(antimalwareconfig, url_link_final, tenant1key):
     console.log("Getting Anti-Malware configuration from Tenant 1")
     for count, amconfig in enumerate(antimalwareconfig):
         if int(amconfig) != 0:
-            payload = {}
             url = url_link_final + "api/antimalwareconfigurations/" + str(amconfig)
             response = safe_request(tenant1key, "GET", url, payload={}, cert=cert)
             describe = str(response.text)
@@ -108,14 +108,14 @@ def AmconfigTenant2(allamconfig, NEW_API_KEY):
     return allamconfigdict
 
 
-def AmReplaceConfig(allofpolicy, allamconfigdict):
+def AmReplaceConfig(allofpolicy, allamconfigdict, schedule_id_dict):
     count = 0
     for describe in allofpolicy:
 
         def replace_am_id(
             type,
             policy_json_string,
-            newiddict=allamconfigdict,
+            newiddict,
         ):
             policy_json = json.loads(policy_json_string)
             policy_am_json = policy_json["antiMalware"]
@@ -124,11 +124,19 @@ def AmReplaceConfig(allofpolicy, allamconfigdict):
             final_json = json.dumps(policy_json)
             return final_json
 
-        describe_rt = replace_am_id("realTimeScanConfigurationID", describe)
-        describe_man = replace_am_id("manualScanConfigurationID", describe_rt)
-        describe_sch = replace_am_id("scheduledScanConfigurationID", describe_man)
-
-        allofpolicy[count] = describe_sch
+        describe_rt = replace_am_id(
+            "realTimeScanConfigurationID", describe, allamconfigdict
+        )
+        describe_man = replace_am_id(
+            "manualScanConfigurationID", describe_rt, allamconfigdict
+        )
+        describe_sch = replace_am_id(
+            "scheduledScanConfigurationID", describe_man, allamconfigdict
+        )
+        describe_rt_sch = replace_am_id(
+            "realTimeScanScheduleID", describe_sch, schedule_id_dict
+        )
+        allofpolicy[count] = describe_rt_sch
         count = count + 1
     return allofpolicy
 
