@@ -6,7 +6,7 @@ import urllib3
 import json
 from dsmigrator.logging import console
 from dsmigrator.api_config import ComputerGroupsApiInstance
-from dsmigrator.migrator_utils import validate_create_dict, value_exists, rename_json
+from dsmigrator.migrator_utils import validate_create_dict, rename_json
 from deepsecurity.rest import ApiException
 
 cert = False
