@@ -4,6 +4,7 @@ import time
 from time import sleep
 import requests
 import urllib3
+import urllib3
 import json
 from dsmigrator.logging import console
 
@@ -122,7 +123,11 @@ def FirewallDescribe(
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "GET", url, headers=headers, data=payload, verify=cert
+                "GET",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             allfirewallrule.append(describe)
@@ -175,7 +180,11 @@ def FirewallDescribe(
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "POST", url, headers=headers, data=payload, verify=cert
+            "POST",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         taskjson = json.loads(describe)
@@ -203,7 +212,11 @@ def FirewallDescribe(
                                 "Content-Type": "application/json",
                             }
                             response = requests.request(
-                                "POST", url, headers=headers, data=payload, verify=cert
+                                "POST",
+                                url,
+                                headers=headers,
+                                data=payload,
+                                verify=cert,
                             )
                             console.log(
                                 "#" + str(count) + " Firewall rule ID: " + indexid,
@@ -270,7 +283,11 @@ def FirewallCustom(
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             index = describe.find('"ID"')
